%define commit      653bd0400b4413db96b80c807f0f7524f9248adb
%define shortcommit %(c=%{commit}; echo ${c:0:7})
%define commitdate  20241113

Name:           tvheadend
Summary:        TV streaming server
Version:        4.3
Release:        %mkrel 8.git%{commitdate}.2
License:        GPL-3.0-or-later and CC-BY-2.5 and Apache-2.0
URL:            https://tvheadend.org/
Group:          Video/Television
Source0:        https://github.com/tvheadend/tvheadend/archive/%{shortcommit}/%{name}-%{shortcommit}.tar.gz
Source2:        %{name}.png
Source4:        %{name}.conf
Source5:        README.install.urpmi
# Use system queue.h header
Patch0:         %{name}-4.3-use_system_queue.patch
# Fix build with hdhomerun
Patch1:         %{name}-4.3-hdhomerun.patch
# Python 3 fixes for Python bindings
Patch2:         %{name}-4.3-python3.patch
# Fix systemd service and configuration:
# - Fix daemon group (use video to access DVB devices)
# - Add -C option to allow UI access without login at first run
Patch3:         %{name}-4.3-service.patch
# Enforcing system crypto policies, see
# https://fedoraproject.org/wiki/Packaging:CryptoPolicies
Patch5:         %{name}-4.3-crypto_policies.patch
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(liburiparser)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-drm)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  hdhomerun-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  bzip2
BuildRequires:  gzip

Requires(post): pwgen
Requires(pre):  rpm-helper
Requires(post): systemd
Requires(preun): systemd

%description
Tvheadend is a TV streaming server for Linux supporting DVB-S, DVB-S2, DVB-C,
DVB-T, ATSC, IPTV, HDHomeRun, and Analog video (V4L) as input sources.

Tvheadend offers the HTTP (VLC, MPlayer), HTSP (Kodi, Movian) and SAT>IP
streaming.

Multiple EPG sources are supported (over-the-air DVB and ATSC including OpenTV
DVB extensions, XMLTV, PyXML).

The Analog video (V4L) is supported directly up to version 3.4. In recent
version, the pipe:// source (in IPTV network) might be used to obtain the
MPEG-TS stream generated by ffmpeg/libav from a V4L device.

%prep
%autosetup -p0 -n %{name}-%{commit}

%build
%configure \
    --release \
    --disable-dvbscan \
    --disable-tvhcsa \
    --disable-libx264 \
    --disable-libx265 \
    --disable-libfdkaac_static \
    --disable-ffmpeg_static \
    --disable-hdhomerun_static \
    --disable-libfdkaac_static \
    --disable-libopus_static \
    --disable-libtheora_static \
    --disable-libvorbis_static \
    --disable-libvpx_static \
    --disable-libx264_static \
    --disable-libx265_static \
    --enable-libfdkaac \
    --enable-hdhomerun_client \
    --enable-libsystemd_daemon \
    --python=%{python3}

%make_build

%install
%make_install

cp -v %{SOURCE5} .

mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol
cp -v %{SOURCE4} %{buildroot}%{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1

mkdir -p %{buildroot}%{_iconsdir}
cp -v %{SOURCE2} %{buildroot}%{_iconsdir}/%{name}.png

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Tvheadend
Comment=TV streaming server
Exec=%{_bindir}/xdg-open http://localhost:9981/
Icon=%{_iconsdir}/%{name}
Type=Application
Categories=AudioVideo;Video;TV;Recorder;X-Mageia-CrossDesktop;
EOF

install -Dpm 0644 rpm/%{name}.service %{buildroot}%{_unitdir}/%{name}.service
install -Dpm 0644 rpm/%{name}.sysconfig %{buildroot}%{_sysconfdir}/sysconfig/%{name}

chmod +x %{buildroot}%{_bindir}/%name

%pre
# create a user "tvheadend" with a home directory /var/lib/tvheadend
# with no login shell and make him a member of the video group
%_pre_useradd %{name} %{_localstatedir}/lib/%{name} /sbin/nologin
gpasswd -a %{name} video >/dev/null

%post
chown %{name}:root %{_localstatedir}/lib/%{name} 
cd %{_localstatedir}/lib/%{name}
chown -R %{name}:video .hts*

# check if the access control file still has the initial dummy password, and
# replace the dummy password by a random, 12-character pwgen-generated password
if  grep -q '"password": "dummypassword"' %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1; then
  sed -i "s,\"password\": \"dummypassword\",\"password\": \"$(pwgen -s 12 1)\"," %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1
fi

%_post_service %{name}

%preun
%_preun_service %{name}

%files
%doc CONTRIBUTING.md README.md
%doc README.install.urpmi
%license LICENSE.md licenses/gpl-3.0.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_bindir}/%name
%{_bindir}/tv_meta_tmdb.py
%{_bindir}/tv_meta_tvdb.py
%{_bindir}/tvhmeta
%{_unitdir}/%{name}.service
%{_mandir}/man1/%name.1*
%{_iconsdir}/%name.png
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}/

#home directory and config file 
%dir %attr(-,tvheadend,root) %{_localstatedir}/lib/%{name}
%dir %attr(-,tvheadend,video) %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol
%attr(0600,tvheadend,video) %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1



%changelog
* Mon Jun 30 2025 umeabot <umeabot> 4.3-8.git20241113.2.mga10
+ Revision: 2231293
- Mageia 10 Mass Rebuild

* Sun Dec 08 2024 daviddavid <daviddavid> 4.3-8.git20241113.1.mga10
+ Revision: 2122895
- update to git snapshot 20241113
- rebuild for new ffmpeg 7.1

* Sun May 05 2024 daviddavid <daviddavid> 4.3-8.git20240111.1.mga10
+ Revision: 2062195
- update to git snapshot 20240111
- switch to systemd unit from initscripts

* Sun Nov 20 2022 wally <wally> 4.3-7.mga9
+ Revision: 1909447
- add upstream patch to fix use-after-free more properly

* Sun Nov 20 2022 umeabot <umeabot> 4.3-6.mga9
+ Revision: 1909441
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 4.3-5.mga9
+ Revision: 1747419
- rebuild for openssl 3.0.0

* Fri Nov 13 2020 tv <tv> 4.3-4.mga8
+ Revision: 1644985
- fix build on 32bit
- fix build

* Thu Apr 16 2020 umeabot <umeabot> 4.3-3.mga8
+ Revision: 1567730
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%setup_compile_flags

* Tue Oct 02 2018 daviddavid <daviddavid> 4.3-2.mga7
+ Revision: 1315866
- add patch to fix build with gcc8
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Thu Sep 07 2017 guillomovitch <guillomovitch> 4.3-1.mga7
+ Revision: 1151801
- new version 4.3

* Mon Feb 13 2017 eatdirt <eatdirt> 4.0.9-1.mga6
+ Revision: 1086031
- Upgrade to version 4.0.9

* Sun Jan 22 2017 daviddavid <daviddavid> 3.2.18-7.mga6
+ Revision: 1083061
- remove useless BRs on kdelibs4-devel and qt4-devel
- fix Comment key on desktop file

* Mon Feb 08 2016 umeabot <umeabot> 3.2.18-6.mga6
+ Revision: 942884
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.2.18-5.mga5
+ Revision: 741963
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.2.18-4.mga5
+ Revision: 689994
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 3.2.18-3.mga4
+ Revision: 519814
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 3.2.18-2.mga3
+ Revision: 384907
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 anssi <anssi> 3.2.18-1.mga3
+ Revision: 343709
- update group
- new version
- drop now unneeded patches (mandir.patch, cflags.patch)

* Thu Jan 05 2012 doktor5000 <doktor5000> 2.12-1.mga2
+ Revision: 191744
- temporary workaround for compilation with gcc-4.6
- use %%{_bindir} instead of /usr/bin in .desktop file
- remove unused start script from spec
- use %%setup_compile_flags
- drop %%ifarch-applying of patch
- drop %%ifarch-configure
- fix cflags.patch, so that the Makefile does not overwrite our CFLAGS
- add LSB headers to init script, added Default-Stop for runlevels 0 and 6,
  remove commented-out line
- replaced start script with direct call from .desktop file and avoid
  calling tvheadend a second time additionally to the init script
- fix Icon entry in .desktop file, add X-Mageia-CrossDesktop to categories to
  no display it in "More" sub-menu
- use gpasswd instead of usermod -G, since "usermod -G" replaces groups
  instead of adding them
- check for the existence of the dummy password before replacing it with the
  pwgen-generated one, grep/sed the whole string as safety measure
- move manpage to correct location (mandir.patch)
- use %%{_prefix} instead of /usr
- change README.urpmi to README.install.urpmi, change encoding to UTF8,
  proofread & reword README.install.urpmi, remove german parts
- minor cosmetics
- imported package tvheadend


* Mon Dec 12 2011 #shadow# <rpm-mud@arcor.de> 2.12-4mud2010.2
- add automatic generated user password with pwgen

* Tue Dec 07 2011 #shadow# <rpm-mud@arcor.de> 2.12-4mud2010.2
- add config file with login datas
- rework the readme.urpmi file

* Tue Sep 27 2011 #shadow# <rpm-mud@arcor.de> 2.12-3mud2010.2
- rework the menu start script, fix the start problem

* Tue Sep 27 2011 #shadow# <rpm-mud@arcor.de> 2.12-3mud2010.2
- add readme.urpmi file 

* Mon Sep 26 2011 #shadow# <rpm-mud@arcor.de> 2.12-3mud2010.2
- add reload function to init script

* Sun Sep 18 2011 #shadow# <rpm-mud@arcor.de> 2.12-3mud2010.2
- add menu entry based on tamplate from doktor5000

* Sun Sep 18 2011 #shadow# <rpm-mud@arcor.de> 2.12-3mud2010.2
- converting not utf-8 compatible readme file 

* Sun Sep 18 2011 #shadow# <rpm-mud@arcor.de> 2.12-3mud2010.2
- compress manpage with lzma due to faulty installation

* Sat Aug 13 2011 #shadow# <rpm-mud@arcor.de> 2.12-2mud2010.2
- add init script taken from clearos tvheadend package

* Sat Aug 13 2011 #shadow# <rpm-mud@arcor.de> 2.12-2mud2010.2
- add patch0 taken from doktor5000 to fix i586 build problem

* Sun Aug 07 2011 #shadow# <rpm-mud@arcor.de> 2.12-1mud2010.2
- build initial tvheadend-package
